@@ -15,13 +15,10 @@ class NetworkAttachmentDefinition(NamespacedResource):
         raise NotImplementedError(f"{self.kind} does not have status")
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-
-        if self.resource_name is not None:
-            res["metadata"]["annotations"] = {
-                f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/resourceName": self.resource_name
-            }
-        res["spec"] = {}
-        return res
+        super().to_dict()
+        if not self.yaml_file:
+            if self.resource_name is not None:
+                self.res["metadata"]["annotations"] = {
+                    f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/resourceName": self.resource_name
+                }
+            self.res["spec"] = {}
